@@ -3,7 +3,7 @@ use warnings;
 
 package Oh;
 
-our $VERSION = 0.03;
+our $VERSION = 0.04;
 
 use subs qw/error env listp evaluate_element evaluate_list evaluate_function evaluate_builtin evaluate_macro evaluate_lambda find search progn read_element read_string read_list reft/;
 
@@ -798,6 +798,7 @@ sub dumper
   join(' ', map { if (ref eq 'lambda' or ref eq 'macro') { '#lambda' } else { Dumper $_ } } @_);
 }
 
+
 #sbs
 
 
@@ -953,6 +954,13 @@ op
 fun { listp ref $_[0] } 'listp';
 fun { my ($obj, $method, @args) = @_; $obj->$method(@args) } 'method';
 
+op
+{
+  $env->{symbol}->{$_[0]} = evaluate_element $_[1];
+} 'setq-current-env';
+
+
+
 
 #funs
 
@@ -1036,6 +1044,24 @@ fun
   \@list;
 } 'cdr';
 
+fun
+{
+  my $package = shift;
+  for my $name (@_)
+  {
+    if (listp ref $name)
+    {
+      print "binding $name\n";
+      my ($lisp_name, $perl_name) = @$name;
+      &fun(get_sub($package . '::' . $perl_name), $lisp_name);
+    }
+    else
+    {
+      print "binding $name\n";
+      &fun(get_sub($package . '::' . $name), $name);
+    }
+  }
+} 'bindings';
 
 interpret_string <<'oh';
 (macro fun (name args . code)
@@ -1056,7 +1082,7 @@ interpret_string <<'oh';
 (macro define (name . value)
   (if (listp name)
    `(fun ,(car name) ,(cdr name) ,@value)
-   `(setq ,name ,(car value))))
+   `(setq-current-env ,name ,(car value))))
 
 oh
 
